/**
 * Copyright (c) 2008 by The Shoe Shine Boy.
 * 
 * This file is part of Mail Blaster.
 * 
 * Mail Blaster is free software: you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or (at your 
 * option) any later version.
 *
 * Mail Blaster is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License 
 * along with Mail Blaster. If not, see <http://www.gnu.org/licenses/>.
 */
package com.gt.mailblaster.mailer;

import java.io.File;
import java.util.Observable;

/**
 * The abstract class that defines a mailer.
 * 
 * @author The Shoe Shine Boy
 *
 */
public abstract class AbstractMailer extends Observable {

	public void notifyObservers(Object arg) {
		setChanged();
		super.notifyObservers(arg);
	}

	/**
	 * Child classes should implement this method to send a single mail in one go filling 
	 * up all the information provided as arguments.
	 * 
	 * @param to				Array of String objects representing the to fields.
	 * @param subject			The mail subject provided as a String Object.
	 * @param body				The mail body provided as a String Object.
	 * @param sendAsHTML		boolean flag - if true then body must be sent as "text/html"
	 * @param attachments		Array of File objects representing the attachments.
	 * @throws MailerException	Throw this exception if mailing fails.
	 */
	public abstract void mail(String[] to, String subject, String body, 
			boolean sendAsHTML, File[] attachments) throws MailerException;

}
